@@ -14,9 +14,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-readonly ROOT_DIR="/go/src/github.com/knative/client"
-source ${ROOT_DIR}/scripts/test-infra/library.sh
-source ${ROOT_DIR}/scripts/test-infra/e2e-tests.sh
+readonly ROOT_DIR=$(dirname $0)/..
+source ${ROOT_DIR}/vendor/knative.dev/hack/library.sh
+source ${ROOT_DIR}/vendor/knative.dev/hack/e2e-tests.sh
 
 readonly KN_DEFAULT_TEST_IMAGE="gcr.io/knative-samples/helloworld-go"
 readonly SERVING_NAMESPACE="knative-serving"
@@ -27,7 +27,7 @@ readonly OLM_NAMESPACE="openshift-marketplace"
 
 # if you want to setup the nightly serving/eventing, set `release-next` OR
 # set release branch name for example: release-v0.19.1
-readonly SERVING_BRANCH="release-next"
+readonly SERVING_BRANCH="release-v0.19.0"
 # Pin the version due to issue in current nightly version
 readonly EVENTING_BRANCH="release-v0.19.2"
 
@@ -62,7 +62,7 @@ build_knative_client() {
   ./hack/build.sh -x || failed=1
 
   if [[ $failed -eq 0 ]]; then
-    mv kn-linux-amd64 kn
+    mv kn-linux-$(go env GOARCH) kn
   fi
 
   return $failed
@@ -81,7 +81,7 @@ run_client_e2e_tests(){
   header "Running e2e tests"
   local failed=0
   # Add local dir to have access to built kn
-  export PATH=$PATH:${ROOT_DIR}
+  export PATH=$PATH:${REPO_ROOT_DIR}
   export GO111MODULE=on
   # In CI environment GOFLAGS is set to '-mod=vendor', unsetting it and providing explicit flag below
   # while invoking go e2e tests. Unsetting to keep using -mod=vendor irrespective of whether GOFLAGS is set or not.
@@ -202,6 +202,11 @@ install_serverless_operator_branch() {
   # environment as a switch to use CI built images, we want pre-built images of k-s-o and k-o-i
   unset OPENSHIFT_BUILD_NAMESPACE
   unset OPENSHIFT_CI
+
+  # Replace deprecated registry.svc.ci with registry.ci until release branch is fixed
+  sed -i 's|registry.svc.ci.openshift.org/openshift/openshift-serverless-v1.13.0|registry.ci.openshift.org/openshift/openshift-serverless-v1.13.0|g' olm-catalog/serverless-operator/manifests/serverless-operator.clusterserviceversion.yaml
+  cat olm-catalog/serverless-operator/manifests/serverless-operator.clusterserviceversion.yaml
+
   # Install all components Serving,Eventing,Strimzi and Kafka
   SCALE_UP=6 make install-all || failed=1
   subheader "Successfully installed serverless operator."
