@@ -37,6 +37,7 @@ import (
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/watch"
 	clienttesting "k8s.io/client-go/testing"
+	"knative.dev/client/pkg/kn/flags"
 	"knative.dev/serving/pkg/apis/serving"
 	servingv1 "knative.dev/serving/pkg/apis/serving/v1"
 )
@@ -120,7 +121,7 @@ func fakeServiceUpdate(original *servingv1.Service, args []string) (
 	return
 }
 
-func TestServcieUpdateNoFlags(t *testing.T) {
+func TestServiceUpdateNoFlags(t *testing.T) {
 	orig := newEmptyService()
 
 	action, _, _, err := fakeServiceUpdate(orig, []string{"service", "update", "foo"})
@@ -142,7 +143,7 @@ func TestServiceUpdateImageSync(t *testing.T) {
 	orig := newEmptyService()
 
 	template := &orig.Spec.Template
-	err := servinglib.UpdateImage(template, "gcr.io/foo/bar:baz")
+	err := flags.UpdateImage(&template.Spec.PodSpec, "gcr.io/foo/bar:baz")
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -164,7 +165,7 @@ func TestServiceUpdateImage(t *testing.T) {
 	orig := newEmptyService()
 
 	template := &orig.Spec.Template
-	err := servinglib.UpdateImage(template, "gcr.io/foo/bar:baz")
+	err := flags.UpdateImage(&template.Spec.PodSpec, "gcr.io/foo/bar:baz")
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -215,7 +216,7 @@ func TestServiceUpdateCommand(t *testing.T) {
 
 	origTemplate := &orig.Spec.Template
 
-	err := servinglib.UpdateContainerCommand(origTemplate, "./start")
+	err := flags.UpdateContainerCommand(&origTemplate.Spec.PodSpec, "./start")
 	assert.NilError(t, err)
 
 	action, updated, _, err := fakeServiceUpdate(orig, []string{
@@ -232,7 +233,7 @@ func TestServiceUpdateArg(t *testing.T) {
 
 	origTemplate := orig.Spec.Template
 
-	err := servinglib.UpdateContainerArg(&origTemplate, []string{"myArg0"})
+	err := flags.UpdateContainerArg(&origTemplate.Spec.PodSpec, []string{"myArg0"})
 	assert.NilError(t, err)
 
 	action, updated, _, err := fakeServiceUpdate(orig, []string{
@@ -456,7 +457,7 @@ func TestServiceUpdateEnv(t *testing.T) {
 		{Name: "OTHEREXISTING"},
 	}
 
-	servinglib.UpdateImage(template, "gcr.io/foo/bar:baz")
+	flags.UpdateImage(&template.Spec.PodSpec, "gcr.io/foo/bar:baz")
 
 	action, updated, _, err := fakeServiceUpdate(orig, []string{
 		"service", "update", "foo", "-e", "TARGET=Awesome", "--env", "EXISTING-", "--env=OTHEREXISTING-=whatever", "--no-wait"})
@@ -482,7 +483,7 @@ func TestServiceUpdatePinsToDigestWhenAsked(t *testing.T) {
 
 	template := &orig.Spec.Template
 	delete(template.Annotations, servinglib.UserImageAnnotationKey)
-	err := servinglib.UpdateImage(template, "gcr.io/foo/bar:baz")
+	err := flags.UpdateImage(&template.Spec.PodSpec, "gcr.io/foo/bar:baz")
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -505,7 +506,7 @@ func TestServiceUpdatePinsToDigestWhenPreviouslyDidSo(t *testing.T) {
 	orig := newEmptyService()
 
 	template := &orig.Spec.Template
-	err := servinglib.UpdateImage(template, "gcr.io/foo/bar:baz")
+	err := flags.UpdateImage(&template.Spec.PodSpec, "gcr.io/foo/bar:baz")
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -528,7 +529,7 @@ func TestServiceUpdateDoesntPinToDigestWhenUnAsked(t *testing.T) {
 	orig := newEmptyService()
 
 	template := orig.Spec.Template
-	err := servinglib.UpdateImage(&template, "gcr.io/foo/bar:baz")
+	err := flags.UpdateImage(&template.Spec.PodSpec, "gcr.io/foo/bar:baz")
 	assert.NilError(t, err)
 
 	action, updated, _, err := fakeServiceUpdate(orig, []string{
@@ -552,7 +553,7 @@ func TestServiceUpdateDoesntPinToDigestWhenPreviouslyDidnt(t *testing.T) {
 	template := &orig.Spec.Template
 	delete(template.Annotations, servinglib.UserImageAnnotationKey)
 
-	err := servinglib.UpdateImage(template, "gcr.io/foo/bar:baz")
+	err := flags.UpdateImage(&template.Spec.PodSpec, "gcr.io/foo/bar:baz")
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -577,7 +578,7 @@ func TestServiceUpdateRequestsLimitsCPU(t *testing.T) {
 	service := createMockServiceWithResources(t, "250", "64Mi", "1000m", "1024Mi")
 
 	action, updated, _, err := fakeServiceUpdate(service, []string{
-		"service", "update", "foo", "--requests-cpu", "500m", "--limits-cpu", "1000m", "--no-wait"})
+		"service", "update", "foo", "--request", "cpu=500m", "--limit", "cpu=1000m", "--no-wait"})
 	if err != nil {
 		t.Fatal(err)
 	} else if !action.Matches("update", "services") {
@@ -615,7 +616,7 @@ func TestServiceUpdateRequestsLimitsMemory(t *testing.T) {
 	service := createMockServiceWithResources(t, "100m", "64Mi", "1000m", "1024Mi")
 
 	action, updated, _, err := fakeServiceUpdate(service, []string{
-		"service", "update", "foo", "--requests-memory", "128Mi", "--limits-memory", "2048Mi", "--no-wait"})
+		"service", "update", "foo", "--request", "memory=128Mi", "--limit", "memory=2048Mi", "--no-wait"})
 	if err != nil {
 		t.Fatal(err)
 	} else if !action.Matches("update", "services") {
@@ -654,8 +655,8 @@ func TestServiceUpdateRequestsLimitsCPU_and_Memory(t *testing.T) {
 
 	action, updated, _, err := fakeServiceUpdate(service, []string{
 		"service", "update", "foo",
-		"--requests-cpu", "500m", "--limits-cpu", "2000m",
-		"--requests-memory", "128Mi", "--limits-memory", "2048Mi", "--no-wait"})
+		"--request", "cpu=500m,memory=128Mi",
+		"--limit", "cpu=2000m,memory=2048Mi", "--no-wait"})
 	if err != nil {
 		t.Fatal(err)
 	} else if !action.Matches("update", "services") {
