@@ -21,8 +21,8 @@ import (
 
 	"github.com/spf13/cobra"
 	v1alpha2 "knative.dev/eventing/pkg/apis/sources/v1alpha2"
-	duckv1 "knative.dev/pkg/apis/duck/v1"
 
+	"knative.dev/client/lib/printing"
 	"knative.dev/client/pkg/kn/commands"
 	"knative.dev/client/pkg/printers"
 )
@@ -65,7 +65,7 @@ func NewAPIServerDescribeCommand(p *commands.KnParams) *cobra.Command {
 				return err
 			}
 
-			writeSink(dw, apiSource.Spec.Sink)
+			printing.DescribeSink(dw, "Sink", apiSource.Namespace, &apiSource.Spec.Sink)
 			dw.WriteLine()
 			if err := dw.Flush(); err != nil {
 				return err
@@ -107,20 +107,6 @@ func writeResources(dw printers.PrefixWriter, apiVersionKindSelectors []v1alpha2
 	}
 }
 
-func writeSink(dw printers.PrefixWriter, sink duckv1.Destination) {
-	subWriter := dw.WriteAttribute("Sink", "")
-	ref := sink.Ref
-	if ref != nil {
-		subWriter.WriteAttribute("Name", sink.Ref.Name)
-		subWriter.WriteAttribute("Namespace", sink.Ref.Namespace)
-		subWriter.WriteAttribute("Kind", fmt.Sprintf("%s (%s)", sink.Ref.Kind, sink.Ref.APIVersion))
-	}
-	uri := sink.URI
-	if uri != nil {
-		subWriter.WriteAttribute("URI", uri.String())
-	}
-}
-
 func writeAPIServerSource(dw printers.PrefixWriter, source *v1alpha2.ApiServerSource, printDetails bool) {
 	commands.WriteMetadata(dw, &source.ObjectMeta, printDetails)
 	dw.WriteAttribute("ServiceAccountName", source.Spec.ServiceAccountName)
