@@ -24,6 +24,7 @@ import (
 	"k8s.io/client-go/rest"
 	"k8s.io/client-go/tools/clientcmd"
 	eventingv1beta1 "knative.dev/eventing/pkg/client/clientset/versioned/typed/eventing/v1beta1"
+	messagingv1beta1 "knative.dev/eventing/pkg/client/clientset/versioned/typed/messaging/v1beta1"
 	sourcesv1alpha2client "knative.dev/eventing/pkg/client/clientset/versioned/typed/sources/v1alpha2"
 	servingv1client "knative.dev/serving/pkg/client/clientset/versioned/typed/serving/v1"
 
@@ -33,18 +34,20 @@ import (
 	clientdynamic "knative.dev/client/pkg/dynamic"
 	knerrors "knative.dev/client/pkg/errors"
 	clienteventingv1beta1 "knative.dev/client/pkg/eventing/v1beta1"
+	clientmessagingv1beta1 "knative.dev/client/pkg/messaging/v1beta1"
 	clientservingv1 "knative.dev/client/pkg/serving/v1"
 )
 
 // KnParams for creating commands. Useful for inserting mocks for testing.
 type KnParams struct {
-	Output            io.Writer
-	KubeCfgPath       string
-	ClientConfig      clientcmd.ClientConfig
-	NewServingClient  func(namespace string) (clientservingv1.KnServingClient, error)
-	NewSourcesClient  func(namespace string) (v1alpha2.KnSourcesClient, error)
-	NewEventingClient func(namespace string) (clienteventingv1beta1.KnEventingClient, error)
-	NewDynamicClient  func(namespace string) (clientdynamic.KnDynamicClient, error)
+	Output             io.Writer
+	KubeCfgPath        string
+	ClientConfig       clientcmd.ClientConfig
+	NewServingClient   func(namespace string) (clientservingv1.KnServingClient, error)
+	NewSourcesClient   func(namespace string) (v1alpha2.KnSourcesClient, error)
+	NewEventingClient  func(namespace string) (clienteventingv1beta1.KnEventingClient, error)
+	NewMessagingClient func(namespace string) (clientmessagingv1beta1.KnMessagingClient, error)
+	NewDynamicClient   func(namespace string) (clientdynamic.KnDynamicClient, error)
 
 	// General global options
 	LogHTTP bool
@@ -66,6 +69,10 @@ func (params *KnParams) Initialize() {
 		params.NewEventingClient = params.newEventingClient
 	}
 
+	if params.NewMessagingClient == nil {
+		params.NewMessagingClient = params.newMessagingClient
+	}
+
 	if params.NewDynamicClient == nil {
 		params.NewDynamicClient = params.newDynamicClient
 	}
@@ -101,6 +108,16 @@ func (params *KnParams) newEventingClient(namespace string) (clienteventingv1bet
 	return clienteventingv1beta1.NewKnEventingClient(client, namespace), nil
 }
 
+func (params *KnParams) newMessagingClient(namespace string) (clientmessagingv1beta1.KnMessagingClient, error) {
+	restConfig, err := params.RestConfig()
+	if err != nil {
+		return nil, err
+	}
+
+	client, _ := messagingv1beta1.NewForConfig(restConfig)
+	return clientmessagingv1beta1.NewKnMessagingClient(client, namespace), nil
+}
+
 func (params *KnParams) newDynamicClient(namespace string) (clientdynamic.KnDynamicClient, error) {
 	restConfig, err := params.RestConfig()
 	if err != nil {
