@@ -31,11 +31,11 @@ var GitRevision string
 // update this var as we add more deps
 var apiVersions = map[string][]string{
 	"serving": {
-		"serving.knative.dev/v1 (knative-serving v0.14.0)",
+		"serving.knative.dev/v1 (knative-serving v0.19.0)",
 	},
 	"eventing": {
-		"sources.knative.dev/v1alpha2 (knative-eventing v0.14.1)",
-		"eventing.knative.dev/v1alpha1 (knative-eventing v0.14.1)",
+		"sources.knative.dev/v1alpha2 (knative-eventing v0.19.0)",
+		"eventing.knative.dev/v1beta1 (knative-eventing v0.19.0)",
 	},
 }
 
@@ -50,7 +50,7 @@ type knVersion struct {
 func NewVersionCommand(p *commands.KnParams) *cobra.Command {
 	versionCmd := &cobra.Command{
 		Use:   "version",
-		Short: "Prints the client version",
+		Short: "Show the version of this client",
 		RunE: func(cmd *cobra.Command, args []string) error {
 			if cmd.Flags().Changed("output") {
 				return printVersionMachineReadable(cmd)
